@@ -14,13 +14,15 @@
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KQuickAddons/QtQuickSettings>
+#include <KStartupInfo>
+#include <KWindowSystem>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 #include <QTextStream>
 #include <QWindow>
-#include <kstartupinfo.h>
 
+#include <QProcessEnvironment>
 #include <QX11Info>
 
 typedef QHash<QString, DiscoverObject::CompactMode> StringCompactMode;
@@ -73,7 +75,8 @@ void processArgs(QCommandLineParser *parser, DiscoverObject *mainWindow)
     if (parser->isSet(QStringLiteral("local-filename")))
         mainWindow->openLocalPackage(QUrl::fromUserInput(parser->value(QStringLiteral("local-filename")), {}, QUrl::AssumeLocalFile));
 
-    foreach (const QString &arg, parser->positionalArguments()) {
+    const auto positionalArguments = parser->positionalArguments();
+    for (const QString &arg : positionalArguments) {
         const QUrl url = QUrl::fromUserInput(arg, {}, QUrl::AssumeLocalFile);
         if (url.isLocalFile())
             mainWindow->openLocalPackage(url);
@@ -84,6 +87,17 @@ void processArgs(QCommandLineParser *parser, DiscoverObject *mainWindow)
     }
 }
 
+static void raiseWindow(QWindow *window)
+{
+    if (QX11Info::isPlatformX11()) {
+        KStartupInfo::setNewStartupId(window, QX11Info::nextStartupId());
+    } else if (KWindowSystem::isPlatformWayland()) {
+        KWindowSystem::setCurrentXdgActivationToken(qEnvironmentVariable("XDG_ACTIVATION_TOKEN"));
+        KWindowSystem::activateWindow(window->winId());
+    }
+    window->raise();
+}
+
 int main(int argc, char **argv)
 {
     // needs to be set before we create the QGuiApplication
@@ -101,7 +115,7 @@ int main(int argc, char **argv)
                      version,
                      i18n("An application explorer"),
                      KAboutLicense::GPL,
-                     i18n("© 2010-2020 Plasma Development Team"));
+                     i18n("© 2010-2021 Plasma Development Team"));
     about.addAuthor(i18n("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org"), QStringLiteral("https://proli.net"), QStringLiteral("apol"));
     about.addAuthor(i18n("Nate Graham"),
                     i18n("Quality Assurance, Design and Usability"),
@@ -113,6 +127,7 @@ int main(int argc, char **argv)
                     QStringLiteral("admin@leinir.dk"),
                     QStringLiteral("https://leinir.dk/"),
                     QStringLiteral("leinir"));
+    about.setBugAddress("https://bugs.kde.org/enter_bug.cgi?product=Discover");
     about.setProductName("discover/discover");
     about.setProgramLogo(app.windowIcon());
 
@@ -130,7 +145,8 @@ int main(int argc, char **argv)
         if (parser->isSet(QStringLiteral("listbackends"))) {
             QTextStream(stdout) << i18n("Available backends:\n");
             DiscoverBackendsFactory f;
-            foreach (const QString &name, f.allBackendNames(false, true))
+            const auto backendNames = f.allBackendNames(false, true);
+            for (const QString &name : backendNames)
                 QTextStream(stdout) << " * " << name << '\n';
             return 0;
         }
@@ -152,14 +168,14 @@ int main(int argc, char **argv)
         }
         QObject::connect(&app, &QCoreApplication::aboutToQuit, mainWindow, &DiscoverObject::deleteLater);
         auto onActivateRequested = [mainWindow](const QStringList &arguments, const QString & /*workingDirectory*/) {
-            if (!mainWindow->rootObject())
-                QCoreApplication::instance()->quit();
-
             auto window = qobject_cast<QWindow *>(mainWindow->rootObject());
-            if (window && QX11Info::isPlatformX11()) {
-                KStartupInfo::setNewStartupId(window, QX11Info::nextStartupId());
+            if (!window) {
+                // Should never happen anyway
+                QCoreApplication::instance()->quit();
+                return;
             }
-            window->raise();
+
+            raiseWindow(window);
 
             if (arguments.isEmpty())
                 return;
@@ -173,7 +189,8 @@ int main(int argc, char **argv)
 
         if (parser->isSet(QStringLiteral("listmodes"))) {
             QTextStream(stdout) << i18n("Available modes:\n");
-            foreach (const QString &mode, mainWindow->modes())
+            const auto modes = mainWindow->modes();
+            for (const QString &mode : modes)
                 QTextStream(stdout) << " * " << mode << '\n';
             delete mainWindow;
             return 0;
