@@ -8,8 +8,8 @@
 #define DISCOVERUPDATE_H
 
 #include <QObject>
-#include <QUrl>
 #include <QSet>
+#include <QUrl>
 
 #include <Transaction/Transaction.h>
 
@@ -19,20 +19,22 @@ class ResourcesUpdatesModel;
 class DiscoverUpdate : public QObject
 {
     Q_OBJECT
-    public:
-        explicit DiscoverUpdate();
-        ~DiscoverUpdate() override;
+public:
+    explicit DiscoverUpdate();
+    ~DiscoverUpdate() override;
 
-        void setOfflineUpdates(bool offline) {
-            m_offlineUpdates = offline;
-        }
-    private:
-        void start();
-        void transactionStatusChanged(Transaction::Status status);
+    void setOfflineUpdates(bool offline)
+    {
+        m_offlineUpdates = offline;
+    }
 
-        ResourcesUpdatesModel* const m_resourcesUpdatesModel;
-        bool m_done = false;
-        bool m_offlineUpdates = false;
+private:
+    void start();
+    void transactionStatusChanged(Transaction::Status status);
+
+    ResourcesUpdatesModel *const m_resourcesUpdatesModel;
+    bool m_done = false;
+    bool m_offlineUpdates = false;
 };
 
 #endif // DISCOVERUPDATE_H
